"use strict";
/**
 * @desc 表格准备完毕hooks
 * @author 邓欢
 */
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
function useGridReady(tableInstance, tableData, onTableReady) {
    return react_1.useCallback((event) => {
        tableInstance.current = event;
        event.api.setRowData(tableData);
        event.api.sizeColumnsToFit();
        event.api.setSuppressClipboardPaste(true);
        /**
         * ag-grid的默认弹窗框父节点是表格对象本身
         * 1. 在我们系统中如果表格没数据时高度只有一行会导致列设置菜单会显示不全，为了解决这个问题之前加了默认的配置为 "popupParent: document.querySelector('body')"
         * 2. 在加了默认弹出父节点为body后导致在行内框架中切换顶部tab弹出框不会消失（因顶部tab不属于我们系统，所以没有触发点击事件弹出框消失不掉）
         * 3. 最终修改为每个页面的表格渲染完成后设置父节点为当前页面的容器
         */
        event.api.setPopupParent(window._currentContainer());
        onTableReady && onTableReady(event);
    }, [onTableReady]);
}
exports.default = useGridReady;
